==> haskell-swagger2-2.2.2-70-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: swagger2
version: 2.2.2
id: swagger2-2.2.2-dCIVE0jOFUIMpmqdDg2oY
key: swagger2-2.2.2-dCIVE0jOFUIMpmqdDg2oY
license: BSD-3-Clause
copyright: (c) 2015-2016, GetShopTV
maintainer: nickolay@getshoptv.com
author: Nickolay Kudasov
homepage: https://github.com/GetShopTV/swagger2
synopsis: Swagger 2.0 data model
description:
    This library is inteded to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.
    .
    The original Swagger 2.0 specification is available at http://swagger.io/specification/.
category: Web, Swagger
abi: 5b35f22d33719f8b5e299a81c369b7a1
exposed: True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.ParamSchema
    Data.Swagger.Schema Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions
import-dirs: /usr/lib/ghc-8.6.2/site-local/swagger2-2.2.2
library-dirs: /usr/lib/ghc-8.6.2/site-local/swagger2-2.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/swagger2-2.2.2
hs-libraries: HSswagger2-2.2.2-dCIVE0jOFUIMpmqdDg2oY
depends:
    aeson-1.4.2.0-GPa03mfYORkG452ywvZ9uU base-4.12.0.0
    base-compat-batteries-0.10.1-6tsd9P8A1gnD9M7HZxcl5T
    bytestring-0.10.8.2 containers-0.6.0.1
    generics-sop-0.3.2.0-1LIoMWx8QIZINcf2OfoAby
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-media-0.7.1.3-7B92MKhk7rgJnZ6fbAqMYu
    insert-ordered-containers-0.2.1.0-Dv3y1rIxguO4v8mQ0YDqVZ
    lens-4.17-F5gFzTWHxWEDDD3kWgDV81 mtl-2.2.2
    network-2.7.0.2-2fEEs0vTvHq3lWAStilHpJ
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.5.0
    transformers-compat-0.6.2-JV1ddSnlm3mL2xw4J4K8Kw
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html: /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-swagger2-2.2.2-72-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: swagger2
version: 2.2.2
id: swagger2-2.2.2-JLLOpUvd0KJF9ErPZDMqZs
key: swagger2-2.2.2-JLLOpUvd0KJF9ErPZDMqZs
license: BSD-3-Clause
copyright: (c) 2015-2016, GetShopTV
maintainer: nickolay@getshoptv.com
author: Nickolay Kudasov
homepage: https://github.com/GetShopTV/swagger2
synopsis: Swagger 2.0 data model
description:
    This library is inteded to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.
    .
    The original Swagger 2.0 specification is available at http://swagger.io/specification/.
category: Web, Swagger
abi: 5e9c33b4ea9e0aa654b4d1caf8a209f2
exposed: True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.ParamSchema
    Data.Swagger.Schema Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions
import-dirs: /usr/lib/ghc-8.6.3/site-local/swagger2-2.2.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/swagger2-2.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/swagger2-2.2.2
hs-libraries: HSswagger2-2.2.2-JLLOpUvd0KJF9ErPZDMqZs
depends:
    aeson-1.4.2.0-BdBVLho0lrWC4iPoef6lEw base-4.12.0.0
    base-compat-batteries-0.10.1-12o4JByy87e4DixlqqFFgt
    bytestring-0.10.8.2 containers-0.6.0.1
    generics-sop-0.3.2.0-1LIoMWx8QIZINcf2OfoAby
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-media-0.7.1.3-7B92MKhk7rgJnZ6fbAqMYu
    insert-ordered-containers-0.2.1.0-G5wZz0C9ZuX6BxwU2Ual3x
    lens-4.17-FbLYzBYXW5f7bjmi9eGvx2 mtl-2.2.2
    network-2.7.0.2-l7ToO0nOP7DBjiP2hy2PR
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.5.0
    transformers-compat-0.6.2-JV1ddSnlm3mL2xw4J4K8Kw
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html: /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
